@@ -16,7 +16,8 @@
 //!     }
 //! );
 //!
-//! #[derive(ByteStructLE, PartialEq, Debug)]
+//! #[derive(ByteStruct, PartialEq, Debug)]
+//! #[byte_struct_le]
 //! struct GIFLogicalScreenDescriptor {
 //!     width: u16,
 //!     height: u16,
@@ -47,14 +48,21 @@
 //! }
 //! ```
 
-pub use byte_struct_derive::{ByteStructLE, ByteStructBE};
+pub use byte_struct_derive::*;
+
+/// A type that can be packed into or unpacked from fixed-size bytes, but the method is unknown yet.
+pub trait ByteStructLen {
+    /// The length of the packed bytes of this type
+    const BYTE_LEN: usize;
+}
 
 /// A data structure that can be packed into or unpacked from raw bytes.
 ///
 /// This trait can be derived by either `#[derive(ByteStructLE)]` or `#[derive(ByteStructBE)]`.
 /// The difference between two macros is byte order specification. `LE` is for little-endian,
-/// and `BE` is for big-endian. All members of the struct to derive must implement `ByteStructImpl`.
-pub trait ByteStruct {
+/// and `BE` is for big-endian. All members of the struct to derive must implement `ByteStructUnspecifiedByteOrder`.
+/// One can implement this trait for custom types in order to pack or unpack an object in a special way.
+pub trait ByteStruct: ByteStructLen {
     /// Packs the struct into raw bytes and write to a slice
     fn write_bytes(&self, bytes: &mut [u8]);
 
@@ -66,180 +74,232 @@ pub trait ByteStruct {
 ///
 /// This trait is implemented for most numeric primitive types,
 /// except for `bool`, `char`, `isize` and `usize`.
-/// This is also implemented for array types whose element type implements `ByteStructImpl`
+///
+/// This is also implemented for array types whose element type implements `ByteStructUnspecifiedByteOrder`
 /// and whose size is between 1 and 32 (inclusive).
 ///
-/// This trait is also implemented for struct with either `#[derive(ByteStructLE)]` or `#[derive(ByteStructBE)]`.
+/// This trait is automatically implemented for all types that implements `ByteStruct`.
+/// In this case, all members of `ByteStructUnspecifiedByteOrder` are direct wrappers of `ByteStruct` members.
 ///
-/// Members in this trait, except for `BYTE_LEN`, are meant to be used by byte_struct internal only.
+/// Members in this trait are meant to be called by byte_struct internal only.
 /// They do not do what one might expect:
-/// the byte orders specified in `read_*_bytes`/`write_*_bytes` functions are only **default byte order**.
+/// the byte orders specified in `read_bytes_default_*` / `write_bytes_default_*` functions
+/// are only **default byte orders**.
 /// The default byte order is only repected when the type itself does not carry byte order specification
-/// (e.g. primitive types). In contrast, since `ByteStruct`-derived structures always have byte order specification,
-/// the default byte order has no effect on them, and the three versions of read / write functions,
-/// `_le_`, `_be_` and no-spec from `ByteStruct`, behave exactly the same.
+/// (e.g. primitive types).
+/// In contrast, since `ByteStruct` types always have fixed packing method,
+/// the default byte order has no effect on them, and the three versions of read / write functions for them,
+/// `_default_le`, `_default_be` and no-spec from `ByteStruct`, behave exactly the same.
 ///
-/// In some cases, one might want to implement `ByteStructImpl` for custom types
-/// so that they can be members of `ByteStruct`-derived structures.
-pub trait ByteStructImpl {
-    /// The length of the byte representation of this type
-    const BYTE_LEN: usize;
-
+/// One can implement this trait for custom types in order to pack or unpack an object in a special way,
+/// but only when the said type changes its packing method depending on the default byte order.
+/// An example for this is a custom fixed-size large integer type.
+/// If the packing method is independent from the default byte order, please implement `ByteStruct` instead.
+pub trait ByteStructUnspecifiedByteOrder: ByteStructLen {
     /// Packs the object into raw bytes with little-endian as the default byte order
-    fn write_le_bytes(&self, bytes: &mut [u8]);
+    fn write_bytes_default_le(&self, bytes: &mut [u8]);
 
     /// Unpacks raw bytes into a new object with little-endian as the default byte order
-    fn read_le_bytes(bytes: &[u8]) -> Self;
+    fn read_bytes_default_le(bytes: &[u8]) -> Self;
 
     /// Packs the object into raw bytes with big-endian as the default byte order
-    fn write_be_bytes(&self, bytes: &mut [u8]);
+    fn write_bytes_default_be(&self, bytes: &mut [u8]);
 
     /// Unpacks raw bytes into a new object with big-endian as the default byte order
-    fn read_be_bytes(bytes: &[u8]) -> Self;
+    fn read_bytes_default_be(bytes: &[u8]) -> Self;
 }
 
-impl ByteStructImpl for u8 {
+impl<T: ByteStruct> ByteStructUnspecifiedByteOrder for T {
+    /// A wrapper of `ByteStruct::write_bytes`
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
+        self.write_bytes(bytes);
+    }
+
+    /// A wrapper of `ByteStruct::read_bytes`
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
+        Self::read_bytes(bytes)
+    }
+
+    /// A wrapper of `ByteStruct::write_bytes`
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
+        self.write_bytes(bytes);
+    }
+
+    /// A wrapper of `ByteStruct::read_bytes`
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
+        Self::read_bytes(bytes)
+    }
+}
+
+impl ByteStructLen for u8 {
     const BYTE_LEN: usize = 1;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for u8 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         u8::from_le_bytes([bytes[0]])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         u8::from_be_bytes([bytes[0]])
     }
 }
 
-impl ByteStructImpl for i8 {
+impl ByteStructLen for i8 {
     const BYTE_LEN: usize = 1;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for i8 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         i8::from_le_bytes([bytes[0]])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         i8::from_be_bytes([bytes[0]])
     }
 }
 
-impl ByteStructImpl for u16 {
+impl ByteStructLen for u16 {
     const BYTE_LEN: usize = 2;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for u16 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         u16::from_le_bytes([bytes[0], bytes[1]])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         u16::from_be_bytes([bytes[0], bytes[1]])
     }
 }
 
-impl ByteStructImpl for i16 {
+impl ByteStructLen for i16 {
     const BYTE_LEN: usize = 2;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for i16 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         i16::from_le_bytes([bytes[0], bytes[1]])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         i16::from_be_bytes([bytes[0], bytes[1]])
     }
 }
 
-impl ByteStructImpl for u32 {
+impl ByteStructLen for u32 {
     const BYTE_LEN: usize = 4;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for u32 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         u32::from_le_bytes([bytes[0], bytes[1], bytes[2], bytes[3]])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         u32::from_be_bytes([bytes[0], bytes[1], bytes[2], bytes[3]])
     }
 }
 
-impl ByteStructImpl for i32 {
+impl ByteStructLen for i32 {
     const BYTE_LEN: usize = 4;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for i32 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         i32::from_le_bytes([bytes[0], bytes[1], bytes[2], bytes[3]])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         i32::from_be_bytes([bytes[0], bytes[1], bytes[2], bytes[3]])
     }
 }
 
-impl ByteStructImpl for u64 {
+impl ByteStructLen for u64 {
     const BYTE_LEN: usize = 8;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for u64 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         u64::from_le_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7]])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         u64::from_be_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7]])
     }
 }
 
-impl ByteStructImpl for i64 {
+impl ByteStructLen for i64 {
     const BYTE_LEN: usize = 8;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for i64 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         i64::from_le_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7]])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         i64::from_be_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7]])
     }
 }
 
-impl ByteStructImpl for u128 {
+impl ByteStructLen for u128 {
     const BYTE_LEN: usize = 16;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for u128 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         u128::from_le_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7],
@@ -247,10 +307,10 @@ impl ByteStructImpl for u128 {
             bytes[12], bytes[13], bytes[14], bytes[15],
             ])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         u128::from_be_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7],
@@ -259,22 +319,25 @@ impl ByteStructImpl for u128 {
     }
 }
 
-impl ByteStructImpl for i128 {
+impl ByteStructLen for i128 {
     const BYTE_LEN: usize = 16;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for i128 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         i128::from_le_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7],
             bytes[8], bytes[9], bytes[10], bytes[11],
             bytes[12], bytes[13], bytes[14], bytes[15]])
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         i128::from_be_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7],
@@ -283,36 +346,42 @@ impl ByteStructImpl for i128 {
     }
 }
 
-impl ByteStructImpl for f32 {
+impl ByteStructLen for f32 {
     const BYTE_LEN: usize = 4;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for f32 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_bits().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         f32::from_bits(u32::from_le_bytes([bytes[0], bytes[1], bytes[2], bytes[3]]))
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_bits().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         f32::from_bits(u32::from_be_bytes([bytes[0], bytes[1], bytes[2], bytes[3]]))
     }
 }
 
-impl ByteStructImpl for f64 {
+impl ByteStructLen for f64 {
     const BYTE_LEN: usize = 8;
-    fn write_le_bytes(&self, bytes: &mut [u8]) {
+}
+
+impl ByteStructUnspecifiedByteOrder for f64 {
+    fn write_bytes_default_le(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_bits().to_le_bytes()[..]);
     }
-    fn read_le_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_le(bytes: &[u8]) -> Self {
         f64::from_bits(u64::from_le_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7]]))
     }
-    fn write_be_bytes(&self, bytes: &mut [u8]) {
+    fn write_bytes_default_be(&self, bytes: &mut [u8]) {
         bytes.copy_from_slice(&self.clone().to_bits().to_be_bytes()[..]);
     }
-    fn read_be_bytes(bytes: &[u8]) -> Self {
+    fn read_bytes_default_be(bytes: &[u8]) -> Self {
         f64::from_bits(u64::from_le_bytes([
             bytes[0], bytes[1], bytes[2], bytes[3],
             bytes[4], bytes[5], bytes[6], bytes[7]]))
@@ -321,45 +390,48 @@ impl ByteStructImpl for f64 {
 
 macro_rules! byte_struct_array {
     ($x:expr) => {
-        impl<T: ByteStructImpl> ByteStructImpl for [T; $x] {
+        impl<T: ByteStructLen> ByteStructLen for [T; $x] {
             const BYTE_LEN: usize = ($x) * T::BYTE_LEN;
-            fn write_le_bytes(&self, bytes: &mut [u8]) {
+        }
+
+        impl<T: ByteStructUnspecifiedByteOrder> ByteStructUnspecifiedByteOrder for [T; $x] {
+            fn write_bytes_default_le(&self, bytes: &mut [u8]) {
                 let mut pos = 0;
                 let len = T::BYTE_LEN;
                 for i in 0 .. ($x) {
-                    self[i].write_le_bytes(&mut bytes[pos .. pos + len]);
+                    self[i].write_bytes_default_le(&mut bytes[pos .. pos + len]);
                     pos += len;
                 }
             }
-            fn read_le_bytes(bytes: &[u8]) -> Self {
+            fn read_bytes_default_le(bytes: &[u8]) -> Self {
                 let mut pos = 0;
                 let len = T::BYTE_LEN;
                 let mut result: Self;
                 unsafe {
                     result = std::mem::uninitialized();
                     for i in 0 .. ($x) {
-                        std::ptr::write(&mut result[i], <T>::read_le_bytes(&bytes[pos .. pos + len]));
+                        std::ptr::write(&mut result[i], <T>::read_bytes_default_le(&bytes[pos .. pos + len]));
                         pos += len;
                     }
                 }
                 result
             }
-            fn write_be_bytes(&self, bytes: &mut [u8]) {
+            fn write_bytes_default_be(&self, bytes: &mut [u8]) {
                 let mut pos = 0;
                 let len = T::BYTE_LEN;
                 for i in 0 .. ($x) {
-                    self[i].write_be_bytes(&mut bytes[pos .. pos + len]);
+                    self[i].write_bytes_default_be(&mut bytes[pos .. pos + len]);
                     pos += len;
                 }
             }
-            fn read_be_bytes(bytes: &[u8]) -> Self {
+            fn read_bytes_default_be(bytes: &[u8]) -> Self {
                 let mut pos = 0;
                 let len = T::BYTE_LEN;
                 let mut result: Self;
                 unsafe {
                     result = std::mem::uninitialized();
                     for i in 0 .. ($x) {
-                        std::ptr::write(&mut result[i], <T>::read_be_bytes(&bytes[pos .. pos + len]));
+                        std::ptr::write(&mut result[i], <T>::read_bytes_default_be(&bytes[pos .. pos + len]));
                         pos += len;
                     }
                 }
@@ -380,10 +452,10 @@ bsa5!(1);
 byte_struct_array!(100);
 byte_struct_array!(3000);
 
-/// Generates a structure that implements `ByteStructImpl` with bit field semantics.
+/// Generates a structure that implements `ByteStructUnspecifiedByteOrder` with bit field semantics.
 ///
 /// The bit fields are packed to / unpacked from the base integer type,
-/// which is then packed / unpacked using the primitive type's `ByteStructImpl` implementation.
+/// which is then packed / unpacked using the primitive type's `ByteStructUnspecifiedByteOrder` implementation.
 /// Therefore, the byte order of bit fields is unspecified internally, and is only specified
 /// by the parent structure that derives `ByteStructLE`, `ByteStructBE`, just like all primitive
 /// types.
@@ -427,7 +499,7 @@ byte_struct_array!(3000);
 ///     pub z: u16,
 /// }
 ///
-/// impl ByteStructImpl for SampleBitField {
+/// impl ByteStructUnspecifiedByteOrder for SampleBitField {
 ///     ...
 /// }
 /// ```
@@ -473,19 +545,22 @@ macro_rules! bitfields{
             }
         }
 
-        impl ByteStructImpl for $name {
+        impl ByteStructLen for $name {
             const BYTE_LEN: usize = <$base>::BYTE_LEN;
-            fn write_le_bytes(&self, bytes: &mut [u8]) {
-                self.to_raw().write_le_bytes(bytes);
+        }
+
+        impl ByteStructUnspecifiedByteOrder for $name {
+            fn write_bytes_default_le(&self, bytes: &mut [u8]) {
+                self.to_raw().write_bytes_default_le(bytes);
             }
-            fn read_le_bytes(bytes: &[u8]) -> Self {
-                <$name>::from_raw(<$base>::read_le_bytes(bytes))
+            fn read_bytes_default_le(bytes: &[u8]) -> Self {
+                <$name>::from_raw(<$base>::read_bytes_default_le(bytes))
             }
-            fn write_be_bytes(&self, bytes: &mut [u8]) {
-                self.to_raw().write_be_bytes(bytes);
+            fn write_bytes_default_be(&self, bytes: &mut [u8]) {
+                self.to_raw().write_bytes_default_be(bytes);
             }
-            fn read_be_bytes(bytes: &[u8]) -> Self {
-                <$name>::from_raw(<$base>::read_be_bytes(bytes))
+            fn read_bytes_default_be(bytes: &[u8]) -> Self {
+                <$name>::from_raw(<$base>::read_bytes_default_be(bytes))
             }
         }
     }
